__version__ = "0.0.4"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(detached from v0.0.4)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'cd856827df6ce1f96654381bd90d6c0447468f10'
__git_head_subject__ = 'Finished release v0.0.4.'
__git_head_message__ = ''
__git_dirty_diff__ = ''